@@ -12,7 +12,7 @@ use constant MORNING   => '08';
 use constant AFTERNOON => '14';
 use constant EVENING   => '20';
 
-our $VERSION = '1.40';
+our $VERSION = '1.43';
 
 sub _no_op
 {
@@ -87,10 +87,10 @@ sub _hourtime_variant
     my ($value, $when) = @_;
     my $hours = $opts->{hours} || 0;
     if ($self->_valid_time(hour => $hours)) {
-        $self->_set(hour => $hours);
+        $self->_set(hour => $hours, minute => 0, second => 0);
         $self->_add_or_subtract({
             when  => $when,
-            unit  => 'hour',
+            unit  => $opts->{unit},
             value => $value,
         });
     }
@@ -383,6 +383,33 @@ sub _first_last_day_unit
     );
 }
 
+sub _variant_last_month
+{
+    my $self = shift;
+    $self->_register_trace;
+    my $opts = pop;
+    my ($day) = @_;
+    $self->_subtract(month => 1);
+    unless (defined $day) {
+        $day = $self->_Days_in_Month($self->{datetime}->year, $self->{datetime}->month);
+    }
+    $self->_set(day => $day);
+}
+
+sub _variant_quarter
+{
+    my $self = shift;
+    $self->_register_trace;
+    my $opts = pop;
+    my ($when) = @_;
+    $self->_subtract(day => $self->{datetime}->day_of_quarter - 1);
+    $self->_add_or_subtract({
+        when  => $when,
+        unit  => $opts->{unit},
+        value => 3,
+    });
+}
+
 1;
 __END__
 
